@@ -24,33 +24,33 @@ class ResponsumCats:
 
     def get_demo(self, did=None, find_text=None, expand=True, frmt='df'):
         """
-        Получить список демографических переменных: все, по id или поиском по названию
+        Получить список демографических переменных: всеx, по id или поиском по названию.
         
         Parameters
         ----------
 
         did : int
-            Идентификатор демографической переменной для того, что бы получить одну переменную. По умолчанию - не задано
-            (None)
+            Идентификатор демографической переменной для того, чтобы получить одну переменную. По умолчанию - не задано
+            (None).
         
         find_text : str
-            Текст для поиска по названию переменной. По умолчанию - не задано (None)
+            Текст для поиска по названию переменной. По умолчанию - не задано (None).
         
         expand : bool
-            Отобразить в таблице (DataFrame) доступные варианты для данной переменной - True/False? По умолчанию - True
+            Отобразить в таблице (DataFrame) доступные варианты для данной переменной - True/False? По умолчанию - True.
         
         frmt: str
-            Формат вывода разультата
+            Формат вывода результата:
             - "df" - DataFrame,
-            - "json" - JSON,
-            По умолчанию - "df"
+            - "json" - JSON.
+            По умолчанию - "df".
             
         
         Returns
         -------
         DataFrame
 
-            DataFrame с демографическими переменными
+            DataFrame с демографическими переменными.
         """
         data = self.msapi_network.send_request('get', '/demo/variables', use_cache=True)
         res = []
@@ -136,34 +136,36 @@ class ResponsumCats:
     @staticmethod
     def get_population(names='Russia0+'):
         """
-            Получить список ID численности населения городов, для фильтра по географии (Россия 100+ или Россия 100-).
+            ! Функция не используется.
+            
+            Получить список ID численности населения городов для фильтра по географии.
             Список строится на основе демографической переменной "Численность населения города" VarId=350.
 
             Parameters
             ----------
 
             names: str
-                Cтрока в которой перечислены география в текстовом виде:
+                Cтрока, в которой перечислены географии в текстовом виде (через пробел, если географий несколько):
 
                 * Russia0+ - Все города
-                * Russia100- - Города с населением менее 100 тыс человек
-                * Russia100+ - Города с населением 100 тыс человек и более
-                * 700+ - Города с населением 700 тыс человек и более
-                * 400-700 - Города с населением от 400 до 700 тыс человек
-                * 100-400 - Города с населением от 100 до 400 тыс человек
+                * Russia100- - Города с населением менее 100 тыс. человек
+                * Russia100+ - Города с населением 100 тыс. человек и более
+                * 700+ - Города с населением 700 тыс. человек и более
+                * 400-700 - Города с населением от 400 до 700 тыс. человек
+                * 100-400 - Города с населением от 100 до 400 тыс. человек
 
-                Если список не задан или пустой, возвращаются численность для Russia0+
+                Если список не задан или пустой, возвращается численность для Russia0+.
 
             Returns
             -------
 
             list
-                Список идентификаторов Численности населения городов для заданных географий
+                Список идентификаторов Численности населения городов для заданных географий.
 
             Examples
             --------
 
-            Получим список идентификаторов для России 100+
+            Получим список идентификаторов для России 100+:
 
             >>> import sys
             >>> sys.path.append("../../mediascope-api/")
@@ -200,14 +202,14 @@ class ResponsumCats:
     @staticmethod
     def get_usetype(usetype_names='all'):
         """
-        Получить список ID Типов пользования Интернетом по текстовому описанию
+        Получить список ID типов пользования Интернетом по текстовому описанию.
 
         Parameters
         ----------
 
         usetype_names: str
 
-            Cтрока в которой перечислены Типы пользования интернет.
+            Cтрока, в которой перечислены типы пользования Интернетом (через пробел, если типов пользования Интернетом несколько).
 
             Если не задано или строка пустая - возвращает все устройства.
 
@@ -227,13 +229,13 @@ class ResponsumCats:
 
         list
 
-            Список идентифиаторов Типов пользования Интернетом
+            Список идентификаторов типов пользования Интернетом.
 
 
         Examples
         --------
 
-        Получим список usetype для Desktop и Mobile-web
+        Получим список usetype для Desktop и Mobile-web:
 
         >>> import sys
         >>> sys.path.append("../../mediascope-api/")
@@ -268,7 +270,9 @@ class ResponsumCats:
     @staticmethod
     def get_age_groups(ages='12+'):
         """
-        Получить список ID Возврастных групп для фильтра.
+        ! Функция не используется.
+        
+        Получить список ID Возрастных групп для фильтра.
 
         Список строится на основе демографической переменной "Возрастные группы" VarId=170.
 
@@ -276,7 +280,7 @@ class ResponsumCats:
         ----------
 
         ages: str
-            Cтрока в которой перечислены возврастные группы:
+            Cтрока, в которой перечислены возрастные группы (через пробел, если возрастных групп несколько):
                 * 12+ - Население 12+ лет
                 * 12-17 - Население 12-17 лет
                 * 18-24 - Население 18-24 лет
@@ -286,18 +290,18 @@ class ResponsumCats:
                 * 55-64 - Население 55-64 лет
                 * 65+ - Население 65+ лет
 
-            Если список не задан или пустой, возвращаются возврастные группы для 12+
+            Если список не задан или пустой, возвращаются возврастные группы для 12+.
 
         Returns
         -------
 
         list
-            Список идентификаторов Численности населения городов для заданных географий
+            Список идентификаторов Возрастных групп.
 
         Examples
         --------
 
-        Получим список идентификаторов для населения 12+
+        Получим список идентификаторов для населения 12+:
         
         >>> import sys
         >>> sys.path.append("../../mediascope-api/")
@@ -324,38 +328,38 @@ class ResponsumCats:
         for ut in ages.split(' '):
             i = pop_dict.get(ut)
             if i is None:
-                print(f"Внимание! : Возврастная группа: '{ut}' не найдена.")
+                print(f"Внимание! : Возрастная группа: '{ut}' не найдена.")
             else:
                 data.extend(i)
         return list(set(data))
 
     def get_holdings(self, facility_id, branch='any', find_text=None, use_cache=True):
         """
-        Получить список холдингов - все, по id или поиском по названию. Если id или find_text не заданы, то возвращает
-        все доступные холдинги
+        Получить список холдингов: всеx, по id или поиском по названию.
+        Если branch или find_text не заданы, то возвращает все доступные холдинги.
         
         Parameters
         ----------
         facility_id : str
-            Установка: "desktop", "mobile", "desktop_pre". Обязательный параметр
+            Установка: "desktop", "mobile", "desktop_pre". Обязательный параметр.
 
         branch: str
-            Ветка каталога для поиска
+            Ветка каталога для поиска:
             - any - Поиск во всех ветках (по умолчанию)
-            - holding - Поиск в ветке Холдинги
-            - agency - Поиск в ветке Рекламные агентства
-            - network - Поиск в ветке Рекламные сети
+            - holding - Поиск в ветке "Холдинги"
+            - agency - Поиск в ветке "Рекламные агентства"
+            - network - Поиск в ветке "Рекламные сети"
         
         find_text: str
-            Текст для поиска по названию холдинга. По умолчанию - не задано (None)
+            Текст для поиска по названию холдинга. По умолчанию - не задано (None).
 
         use_cache : bool
-            Использовать кэширование - Да/Нет = True/False
+            Использовать кэширование - Да/Нет (True/False)?
 
         Returns
         -------
         
-        DataFrame с холдингами
+        DataFrame с холдингами.
         
         """
 
@@ -436,22 +440,22 @@ class ResponsumCats:
 
     def get_holding(self, facility_id, hid, find_text=None):
         """
-        Получить холдинг - получает все сайты, секции, субсекции, входящие в холдинг
+        Получить холдинг - получает все сайты, секции, субсекции, входящие в холдинг.
         
         Parameters
         ----------
 
         facility_id : Установка: "desktop", "mobile", "desktop_pre". Обязательный параметр.
         
-        hid : идентификатор холдинга. Обязательный параметр
+        hid : идентификатор холдинга. Обязательный параметр.
         
         
-        find_text : Текст для поиска внутри холдинга по названию: сайта, секции, субсекции. 
+        find_text : Текст для поиска внутри холдинга по названию сайта, секции, субсекции. 
         
         Returns
         -------
         
-        DataFrame с найдеными объектами 
+        DataFrame с найденными объектами.
         
         """
         data = self.msapi_network.send_request('get', '/media/holdings/{}?facility_id={}'.format(hid, facility_id))
@@ -505,10 +509,10 @@ class ResponsumCats:
 
     def load_mediatree(self, facility_id, holdings, reload=False):
         """
-        Загружает список объектов входящих в холдинг из  списку холдингов переданных в параметре holdings,
-        а затем сохраняет ее в DataFrame и внешний кэш-файл.
-        При следующей загрузке данных, если не задан параметр reload=True, и объекты холдинга присутствуют в
-        кэш-файле - холдинг загружается из кэша.
+        Загружает список объектов, входящих в холдинг, из  списка холдингов, переданных в параметре holdings,
+        а затем сохраняет его в DataFrame и внешний кэш-файл.
+        При следующей загрузке данных, если не задан параметр reload=True и объекты холдинга присутствуют в
+        кэш-файле, холдинг загружается из кэша.
         Не рекомендуется передавать большой список холдингов на загрузку, т.к. получение каждого отдельного холдинга
         занимает время.
         
@@ -520,20 +524,20 @@ class ResponsumCats:
             Установка: "desktop", "mobile", "desktop_pre". Обязательный параметр.
         
         holdings : DataFrame
-            Список холдингов, по которым нужно нужно получить их состав
+            Список холдингов, по которым нужно получить их состав.
         
         
         reload : bool
             Флаг перезагрузки: 
-                True - загружает информацию по холдингам без использования кэш-файла, т.е. получает информацию с сервера 
+                True - загружает информацию по холдингам без использования кэш-файла, т.е. получает информацию с сервера.
                 False - использует кэш-файл.
-            Рекомендуется переодически вызывать функцию с параметром reload=True, что бы получить актуальный
-            состав холдинга
+            Рекомендуется периодически вызывать функцию с параметром reload=True, чтобы получить актуальный
+            состав холдинга.
         
         Returns
         -------
         
-        DataFrame с найдеными объектами входящими в список холдингов
+        DataFrame с найденными объектами, входящими в список холдингов.
         
         """
 
@@ -565,24 +569,24 @@ class ResponsumCats:
 
     def find_media(self, find_text, branch='any', find_in=None, limit=None):
         """
-        Поиск по Медиа-дереву
+        Поиск по медиа-дереву.
 
         Parameters
         ----------
 
         find_text: str
 
-            Поисковое выражение по которуму осуществляется поиск.
+            Поисковое выражение, по которому осуществляется поиск.
             Ищется вхождение выражения в любое из полей, если поля не ограничены списком find_in.
 
-        branch: Ветка каталога для поиска
+        branch: Ветка каталога для поиска:
             - any - Поиск во всех ветках (по умолчанию)
-            - holding - Поиск в ветке Холдинги
-            - agency - Поиск в ветке Рекламные агентства
-            - network - Поиск в ветке Рекламные сети
+            - holding - Поиск в ветке "Холдинги"
+            - agency - Поиск в ветке "Рекламные агентства"
+            - network - Поиск в ветке "Рекламные сети"
 
         find_in: list
-            Список полей каталога по которым осуществляется поиск:
+            Список полей каталога, по которым осуществляется поиск:
             - any - все поля (по умолчанию)
             - holding
             - site
@@ -591,14 +595,14 @@ class ResponsumCats:
 
         limit : int
             Максимальное количество записей в результате.
-            По умолчанию выводятся все записи
+            По умолчанию выводятся все записи.
 
         Returns
         -------
 
         data : DataFrame
 
-            DataFrame с найденными выражениями
+            DataFrame с найденными выражениями.
 
         """
         fin_list = ['any', 'holding', 'site', 'project', 'section', 'subsection']
@@ -610,7 +614,7 @@ class ResponsumCats:
                 is_error = False
                 for f in find_in:
                     if str(f).lower() not in fin_list:
-                        print(f"Не известный атрибут для поиска: {f}.")
+                        print(f"Неизвестный атрибут для поиска: {f}.")
                         is_error = True
                 if is_error:
                     print(f"Допустимые атрибуты: {(','.join(fin_list))[:-1]}'")
